# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.notification_author_response import NotificationAuthorResponse  # noqa: E501

class TestNotificationAuthorResponse(unittest.TestCase):
    """NotificationAuthorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationAuthorResponse:
        """Test NotificationAuthorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationAuthorResponse`
        """
        model = NotificationAuthorResponse()  # noqa: E501
        if include_optional:
            return NotificationAuthorResponse(
                id = 56,
                email = '',
                role_id = 56,
                first_name = '',
                last_name = '',
                nickname = '',
                avatar_id = ''
            )
        else:
            return NotificationAuthorResponse(
                id = 56,
                email = '',
                role_id = 56,
        )
        """

    def testNotificationAuthorResponse(self):
        """Test NotificationAuthorResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "FCMApi",
    "FCMCredentialsApi",
    "NotificationsApi",
    "ServerRequestsApi",
    "TemplatesApi",
    "UserSettingsApi",
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ContactFooterRequest",
    "ContactFooterResponse",
    "ExpandedNotificationResponse",
    "FCMCredentialsAddRequest",
    "FCMCredentialsResponse",
    "FCMSubscribeRequest",
    "FCMUnsubscribeRequest",
    "HTTPValidationError",
    "Language",
    "LocationInner",
    "MarkNotificationsAsReadInternalRequest",
    "MarkNotificationsAsReadRequest",
    "NotificationAuthorResponse",
    "OverridableSourceTypeResponse",
    "Platform",
    "PortalTemplateOverrideResponse",
    "SendNotificationRequest",
    "SetUserNotificationSettingsRequest",
    "SourceTypeId",
    "TemplateOverrideBatchItem",
    "TemplateOverrideBatchRequest",
    "TemplateOverrideRequest",
    "UserNotificationSettingsResponse",
    "ValidationError",
    "WrappedResponseBool",
    "WrappedResponseContactFooterResponse",
    "WrappedResponseDictStrStr",
    "WrappedResponseInt",
    "WrappedResponseListExpandedNotificationResponse",
    "WrappedResponseListInt",
    "WrappedResponseListOverridableSourceTypeResponse",
    "WrappedResponseListPortalTemplateOverrideResponse",
    "WrappedResponsePortalTemplateOverrideResponse",
    "WrappedResponseUnionFCMCredentialsResponseNoneType",
    "WrappedResponseUserNotificationSettingsResponse",
]

# import apis into sdk package
from notifications_server_connector.api.fcm_api import FCMApi as FCMApi
from notifications_server_connector.api.fcm_credentials_api import FCMCredentialsApi as FCMCredentialsApi
from notifications_server_connector.api.notifications_api import NotificationsApi as NotificationsApi
from notifications_server_connector.api.server_requests_api import ServerRequestsApi as ServerRequestsApi
from notifications_server_connector.api.templates_api import TemplatesApi as TemplatesApi
from notifications_server_connector.api.user_settings_api import UserSettingsApi as UserSettingsApi
from notifications_server_connector.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from notifications_server_connector.api_response import ApiResponse as ApiResponse
from notifications_server_connector.api_client import ApiClient as ApiClient
from notifications_server_connector.configuration import Configuration as Configuration
from notifications_server_connector.exceptions import OpenApiException as OpenApiException
from notifications_server_connector.exceptions import ApiTypeError as ApiTypeError
from notifications_server_connector.exceptions import ApiValueError as ApiValueError
from notifications_server_connector.exceptions import ApiKeyError as ApiKeyError
from notifications_server_connector.exceptions import ApiAttributeError as ApiAttributeError
from notifications_server_connector.exceptions import ApiException as ApiException

# import models into sdk package
from notifications_server_connector.models.contact_footer_request import ContactFooterRequest as ContactFooterRequest
from notifications_server_connector.models.contact_footer_response import ContactFooterResponse as ContactFooterResponse
from notifications_server_connector.models.expanded_notification_response import ExpandedNotificationResponse as ExpandedNotificationResponse
from notifications_server_connector.models.fcm_credentials_add_request import FCMCredentialsAddRequest as FCMCredentialsAddRequest
from notifications_server_connector.models.fcm_credentials_response import FCMCredentialsResponse as FCMCredentialsResponse
from notifications_server_connector.models.fcm_subscribe_request import FCMSubscribeRequest as FCMSubscribeRequest
from notifications_server_connector.models.fcm_unsubscribe_request import FCMUnsubscribeRequest as FCMUnsubscribeRequest
from notifications_server_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from notifications_server_connector.models.language import Language as Language
from notifications_server_connector.models.location_inner import LocationInner as LocationInner
from notifications_server_connector.models.mark_notifications_as_read_internal_request import MarkNotificationsAsReadInternalRequest as MarkNotificationsAsReadInternalRequest
from notifications_server_connector.models.mark_notifications_as_read_request import MarkNotificationsAsReadRequest as MarkNotificationsAsReadRequest
from notifications_server_connector.models.notification_author_response import NotificationAuthorResponse as NotificationAuthorResponse
from notifications_server_connector.models.overridable_source_type_response import OverridableSourceTypeResponse as OverridableSourceTypeResponse
from notifications_server_connector.models.platform import Platform as Platform
from notifications_server_connector.models.portal_template_override_response import PortalTemplateOverrideResponse as PortalTemplateOverrideResponse
from notifications_server_connector.models.send_notification_request import SendNotificationRequest as SendNotificationRequest
from notifications_server_connector.models.set_user_notification_settings_request import SetUserNotificationSettingsRequest as SetUserNotificationSettingsRequest
from notifications_server_connector.models.source_type_id import SourceTypeId as SourceTypeId
from notifications_server_connector.models.template_override_batch_item import TemplateOverrideBatchItem as TemplateOverrideBatchItem
from notifications_server_connector.models.template_override_batch_request import TemplateOverrideBatchRequest as TemplateOverrideBatchRequest
from notifications_server_connector.models.template_override_request import TemplateOverrideRequest as TemplateOverrideRequest
from notifications_server_connector.models.user_notification_settings_response import UserNotificationSettingsResponse as UserNotificationSettingsResponse
from notifications_server_connector.models.validation_error import ValidationError as ValidationError
from notifications_server_connector.models.wrapped_response_bool import WrappedResponseBool as WrappedResponseBool
from notifications_server_connector.models.wrapped_response_contact_footer_response import WrappedResponseContactFooterResponse as WrappedResponseContactFooterResponse
from notifications_server_connector.models.wrapped_response_dict_str_str import WrappedResponseDictStrStr as WrappedResponseDictStrStr
from notifications_server_connector.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt
from notifications_server_connector.models.wrapped_response_list_expanded_notification_response import WrappedResponseListExpandedNotificationResponse as WrappedResponseListExpandedNotificationResponse
from notifications_server_connector.models.wrapped_response_list_int import WrappedResponseListInt as WrappedResponseListInt
from notifications_server_connector.models.wrapped_response_list_overridable_source_type_response import WrappedResponseListOverridableSourceTypeResponse as WrappedResponseListOverridableSourceTypeResponse
from notifications_server_connector.models.wrapped_response_list_portal_template_override_response import WrappedResponseListPortalTemplateOverrideResponse as WrappedResponseListPortalTemplateOverrideResponse
from notifications_server_connector.models.wrapped_response_portal_template_override_response import WrappedResponsePortalTemplateOverrideResponse as WrappedResponsePortalTemplateOverrideResponse
from notifications_server_connector.models.wrapped_response_union_fcm_credentials_response_none_type import WrappedResponseUnionFCMCredentialsResponseNoneType as WrappedResponseUnionFCMCredentialsResponseNoneType
from notifications_server_connector.models.wrapped_response_user_notification_settings_response import WrappedResponseUserNotificationSettingsResponse as WrappedResponseUserNotificationSettingsResponse
